/* A Bison parser, made by GNU Bison 1.875b.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Using locations.  */
#define YYLSP_NEEDED 0

/* If NAME_PREFIX is specified substitute the variables and functions
   names.  */
#define yyparse basic_parse
#define yylex   basic_lex
#define yyerror basic_error
#define yylval  basic_lval
#define yychar  basic_char
#define yydebug basic_debug
#define yynerrs basic_nerrs


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     IF = 258,
     ELSE = 259,
     CLASS = 260,
     RETURN = 261,
     WHILE = 262,
     DYNAMIC = 263,
     STATIC = 264,
     V_TRUE = 265,
     V_FALSE = 266,
     AS = 267,
     END = 268,
     FUNCTION = 269,
     SUB = 270,
     THEN = 271,
     V_NULL = 272,
     VOID = 273,
     CHAR = 274,
     UCHAR = 275,
     SHORT = 276,
     USHORT = 277,
     INT = 278,
     UINT = 279,
     FLOAT = 280,
     DOUBLE = 281,
     STRING = 282,
     BOOL = 283,
     HANDLE = 284,
     IDENTIFIER = 285,
     V_INT = 286,
     V_FLOAT = 287,
     V_STRING = 288
   };
#endif
#define IF 258
#define ELSE 259
#define CLASS 260
#define RETURN 261
#define WHILE 262
#define DYNAMIC 263
#define STATIC 264
#define V_TRUE 265
#define V_FALSE 266
#define AS 267
#define END 268
#define FUNCTION 269
#define SUB 270
#define THEN 271
#define V_NULL 272
#define VOID 273
#define CHAR 274
#define UCHAR 275
#define SHORT 276
#define USHORT 277
#define INT 278
#define UINT 279
#define FLOAT 280
#define DOUBLE 281
#define STRING 282
#define BOOL 283
#define HANDLE 284
#define IDENTIFIER 285
#define V_INT 286
#define V_FLOAT 287
#define V_STRING 288




/* Copy the first part of user declarations.  */
#line 22 "parser/basiclike/langbasic_yacc.y"


#include <xltype.h>
#include <xlexpr.h>
#include <parser/basiclike/xllangbasic.h>
#include <xllang.h>

#ifndef YYDEBUG
#define	YYDEBUG	 0	/* Default to no yydebug support */
#endif



/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 35 "parser/basiclike/langbasic_yacc.y"
typedef union YYSTYPE {
  XLExpr*     expr;
  XLTypeType  xtype;
  xdouble     val_float;
  xint        val_int;
  xchar       val_string[100];
  xchar       identifier[100];
} YYSTYPE;
/* Line 191 of yacc.c.  */
#line 173 "langbasic_yacc.c"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 214 of yacc.c.  */
#line 185 "langbasic_yacc.c"

#if ! defined (yyoverflow) || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# if YYSTACK_USE_ALLOCA
#  define YYSTACK_ALLOC alloca
# else
#  ifndef YYSTACK_USE_ALLOCA
#   if defined (alloca) || defined (_ALLOCA_H)
#    define YYSTACK_ALLOC alloca
#   else
#    ifdef __GNUC__
#     define YYSTACK_ALLOC __builtin_alloca
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC malloc
#  define YYSTACK_FREE free
# endif
#endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */


#if (! defined (yyoverflow) \
     && (! defined (__cplusplus) \
	 || (YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  short yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T yyi;		\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char yysigned_char;
#else
   typedef short yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  2
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   203

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  49
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  32
/* YYNRULES -- Number of rules. */
#define YYNRULES  82
/* YYNRULES -- Number of states. */
#define YYNSTATES  157

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   288

#define YYTRANSLATE(YYX) 						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      35,    36,    45,    44,    41,    46,     2,    47,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,    34,
      42,    48,    43,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,    39,     2,    40,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,    37,     2,    38,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned short yyprhs[] =
{
       0,     0,     3,     4,     7,     9,    11,    13,    15,    16,
      19,    21,    23,    25,    29,    33,    34,    42,    43,    50,
      53,    57,    65,    72,    76,    82,    89,    90,    92,    96,
      97,   109,   110,   120,   122,   124,   126,   128,   130,   132,
     134,   136,   138,   140,   142,   147,   152,   154,   156,   158,
     160,   162,   164,   166,   168,   170,   172,   176,   180,   184,
     188,   193,   198,   202,   206,   211,   216,   221,   222,   224,
     228,   229,   232,   234,   236,   238,   239,   242,   243,   249,
     253,   254,   257
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const yysigned_char yyrhs[] =
{
      50,     0,    -1,    -1,    50,    51,    -1,    57,    -1,    59,
      -1,    62,    -1,     1,    -1,    -1,    52,    53,    -1,    54,
      -1,    55,    -1,     1,    -1,    66,    67,    34,    -1,    66,
       1,    34,    -1,    -1,    66,    67,    56,    35,    61,    36,
      74,    -1,    -1,     5,    67,    58,    37,    52,    38,    -1,
       5,     1,    -1,    67,    12,    66,    -1,    67,    35,    36,
      12,    66,    39,    40,    -1,    67,    39,    31,    40,    12,
      66,    -1,    67,    12,    66,    -1,    67,    39,    40,    12,
      66,    -1,    67,    39,    31,    40,    12,    66,    -1,    -1,
      60,    -1,    61,    41,    60,    -1,    -1,    14,    67,    63,
      35,    61,    36,    12,    66,    74,    13,    14,    -1,    -1,
      15,    67,    64,    35,    61,    36,    74,    13,    15,    -1,
      18,    -1,    19,    -1,    20,    -1,    21,    -1,    22,    -1,
      23,    -1,    24,    -1,    27,    -1,    25,    -1,    26,    -1,
      65,    -1,     8,    42,    67,    43,    -1,     9,    42,    67,
      43,    -1,    30,    -1,    33,    -1,    31,    -1,    32,    -1,
      10,    -1,    11,    -1,    68,    -1,    76,    -1,    70,    -1,
      67,    -1,    69,    44,    69,    -1,    69,    45,    69,    -1,
      69,    46,    69,    -1,    69,    47,    69,    -1,    69,    42,
      48,    69,    -1,    69,    43,    48,    69,    -1,    69,    42,
      69,    -1,    69,    43,    69,    -1,    69,    48,    48,    69,
      -1,    69,    42,    43,    69,    -1,    69,    39,    69,    40,
      -1,    -1,    69,    -1,    71,    41,    69,    -1,    -1,    72,
      73,    -1,    76,    -1,    78,    -1,    80,    -1,    -1,    75,
      72,    -1,    -1,    67,    77,    35,    71,    36,    -1,    69,
      48,    69,    -1,    -1,     4,    74,    -1,     3,    35,    69,
      36,    16,    74,    79,    13,     3,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned short yyrline[] =
{
       0,    65,    65,    67,    71,    72,    73,    74,    81,    83,
      86,    87,    88,    92,    94,    99,    98,   107,   106,   110,
     115,   117,   123,   153,   155,   161,   169,   171,   172,   177,
     176,   187,   186,   199,   200,   201,   202,   203,   204,   205,
     206,   207,   208,   212,   213,   214,   218,   223,   224,   225,
     226,   227,   235,   236,   237,   238,   239,   240,   241,   242,
     243,   244,   245,   246,   247,   248,   252,   255,   257,   258,
     266,   268,   273,   274,   275,   283,   283,   295,   294,   301,
     334,   335,   339
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "IF", "ELSE", "CLASS", "RETURN", "WHILE", 
  "DYNAMIC", "STATIC", "V_TRUE", "V_FALSE", "AS", "END", "FUNCTION", 
  "SUB", "THEN", "V_NULL", "VOID", "CHAR", "UCHAR", "SHORT", "USHORT", 
  "INT", "UINT", "FLOAT", "DOUBLE", "STRING", "BOOL", "HANDLE", 
  "IDENTIFIER", "V_INT", "V_FLOAT", "V_STRING", "';'", "'('", "')'", 
  "'{'", "'}'", "'['", "']'", "','", "'<'", "'>'", "'+'", "'*'", "'-'", 
  "'/'", "'='", "$accept", "input", "decl", "class_field_list", 
  "class_field", "class_prop", "class_method", "@1", "decl_class", "@2", 
  "decl_global", "decl_param", "decl_param_list", "decl_function", "@3", 
  "@4", "type_basic", "type", "identifier", "literal", "expr", 
  "expr_array", "param_list", "code_lines", "code_line", "code_block", 
  "@5", "code_call", "@7", "code_assign", "code_if_else", "code_if", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,    59,    40,    41,   123,   125,    91,
      93,    44,    60,    62,    43,    42,    45,    47,    61
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char yyr1[] =
{
       0,    49,    50,    50,    51,    51,    51,    51,    52,    52,
      53,    53,    53,    54,    54,    56,    55,    58,    57,    57,
      59,    59,    59,    60,    60,    60,    61,    61,    61,    63,
      62,    64,    62,    65,    65,    65,    65,    65,    65,    65,
      65,    65,    65,    66,    66,    66,    67,    68,    68,    68,
      68,    68,    69,    69,    69,    69,    69,    69,    69,    69,
      69,    69,    69,    69,    69,    69,    70,    71,    71,    71,
      72,    72,    73,    73,    73,    75,    74,    77,    76,    78,
      79,    79,    80
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char yyr2[] =
{
       0,     2,     0,     2,     1,     1,     1,     1,     0,     2,
       1,     1,     1,     3,     3,     0,     7,     0,     6,     2,
       3,     7,     6,     3,     5,     6,     0,     1,     3,     0,
      11,     0,     9,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     4,     4,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     3,     3,     3,     3,
       4,     4,     3,     3,     4,     4,     4,     0,     1,     3,
       0,     2,     1,     1,     1,     0,     2,     0,     5,     3,
       0,     2,     9
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char yydefact[] =
{
       2,     0,     1,     7,     0,     0,     0,    46,     3,     4,
       5,     6,     0,    19,    17,    29,    31,     0,     0,     0,
       0,     0,     0,     0,     0,    33,    34,    35,    36,    37,
      38,    39,    41,    42,    40,    43,    20,     0,     0,     8,
      26,    26,     0,     0,     0,     0,     0,    27,     0,     0,
       0,     0,     0,     0,     0,    12,    18,     9,    10,    11,
       0,     0,     0,     0,     0,    75,    44,    45,     0,    22,
       0,    15,     0,    28,    23,     0,     0,     0,    70,    21,
      14,    13,     0,    75,     0,     0,     0,    76,    26,     0,
       0,    24,    32,     0,    50,    51,    48,    49,    47,    55,
      52,     0,    54,    71,    72,    73,    74,     0,     0,    25,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      75,    30,     0,    53,    67,     0,     0,     0,    62,     0,
      63,    56,    57,    58,    59,     0,    79,    16,     0,     0,
      68,     0,    66,    65,    60,    61,    64,    75,    78,     0,
      80,    69,    75,     0,    81,     0,    82
};

/* YYDEFGOTO[NTERM-NUM]. */
static const short yydefgoto[] =
{
      -1,     1,     8,    46,    57,    58,    59,    82,     9,    20,
      10,    47,    48,    11,    21,    22,    35,    36,    99,   100,
     101,   102,   141,    87,   103,    77,    78,   123,   111,   105,
     153,   106
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -83
static const short yypact[] =
{
     -83,    92,   -83,   -83,    14,   -23,   -23,   -83,   -83,   -83,
     -83,   -83,    15,   -83,   -83,   -83,   -83,   133,   -16,   -18,
     -15,   -12,    -9,   -13,    -5,   -83,   -83,   -83,   -83,   -83,
     -83,   -83,   -83,   -83,   -83,   -83,   -83,    39,    13,   -83,
     -23,   -23,   -23,   -23,   133,    48,   112,   -83,   -27,     6,
     -17,    21,    23,    42,   133,   -83,   -83,   -83,   -83,   -83,
      16,    70,   -23,   133,   -19,   -83,   -83,   -83,    44,   -83,
      57,    61,   133,   -83,   -83,    56,    86,   102,   -83,   -83,
     -83,   -83,    81,   -83,   106,   133,    90,    25,   -23,   115,
     133,   -83,   -83,    84,   -83,   -83,   -83,   -83,   -83,    94,
     -83,   101,   -83,   -83,   145,   -83,   -83,    26,   100,   -83,
      93,   127,    93,     0,    69,    93,    93,    93,    93,    79,
     -83,   -83,   125,   -83,    93,   135,    93,    93,   155,    93,
     155,   155,   155,   155,   155,    93,   155,   -83,   147,   117,
     155,    27,   -83,   155,   155,   155,   155,   -83,   -83,    93,
     162,   155,   -83,   163,   -83,   182,   -83
};

/* YYPGOTO[NTERM-NUM].  */
static const yysigned_char yypgoto[] =
{
     -83,   -83,   -83,   -83,   -83,   -83,   -83,   -83,   -83,   -83,
     -83,   124,   -39,   -83,   -83,   -83,   -83,   -38,    -1,   -83,
     -41,   -83,   -83,   -83,   -83,   -82,   -83,   108,   -83,   -83,
     -83,   -83
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -78
static const short yytable[] =
{
      12,    89,    50,    14,    15,    16,    53,     7,    60,    61,
      94,    95,    75,    38,    62,    13,    69,    70,    63,    65,
      37,    76,    39,    40,    62,    74,    41,    17,    93,    42,
       7,    96,    97,    98,    83,    94,    95,    43,   137,    49,
      49,    51,    52,   126,     7,    64,     7,    91,   127,   107,
      18,    44,   109,    45,    19,     7,    96,    97,    98,    71,
      54,    49,   120,   148,    66,   150,    67,    62,   149,   122,
     154,   125,   128,   130,   131,   132,   133,   134,   136,    94,
      95,    68,    72,   140,    79,   143,   144,    49,   145,    94,
      95,    80,     2,     3,   146,    81,    84,     4,    85,     7,
      96,    97,    98,    94,    95,    92,     5,     6,   151,     7,
      96,    97,    98,    55,   121,    86,    88,   129,    90,   110,
      23,    24,     7,     7,    96,    97,    98,   135,   108,   -77,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
     112,    23,    24,   113,   114,   115,   116,   117,   118,   119,
      56,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,   138,   124,   147,   112,   135,   152,   113,   114,   115,
     116,   117,   118,   139,   112,   142,   155,   113,   114,   115,
     116,   117,   118,   139,   -53,   156,    73,   -53,   -53,   -53,
     -53,   -53,   -53,   -53,   112,   104,     0,   113,   114,   115,
     116,   117,   118,   139
};

static const short yycheck[] =
{
       1,    83,    41,     4,     5,     6,    44,    30,    46,    36,
      10,    11,    31,    31,    41,     1,    54,     1,    12,    36,
      36,    40,    37,    35,    41,    63,    35,    12,     3,    42,
      30,    31,    32,    33,    72,    10,    11,    42,   120,    40,
      41,    42,    43,    43,    30,    39,    30,    85,    48,    88,
      35,    12,    90,    40,    39,    30,    31,    32,    33,    60,
      12,    62,    36,    36,    43,   147,    43,    41,    41,   110,
     152,   112,   113,   114,   115,   116,   117,   118,   119,    10,
      11,    39,    12,   124,    40,   126,   127,    88,   129,    10,
      11,    34,     0,     1,   135,    34,    40,     5,    12,    30,
      31,    32,    33,    10,    11,    15,    14,    15,   149,    30,
      31,    32,    33,     1,    14,    13,    35,    48,    12,    35,
       8,     9,    30,    30,    31,    32,    33,    48,    13,    35,
      18,    19,    20,    21,    22,    23,    24,    25,    26,    27,
      39,     8,     9,    42,    43,    44,    45,    46,    47,    48,
      38,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    36,    35,    16,    39,    48,     4,    42,    43,    44,
      45,    46,    47,    48,    39,    40,    13,    42,    43,    44,
      45,    46,    47,    48,    39,     3,    62,    42,    43,    44,
      45,    46,    47,    48,    39,    87,    -1,    42,    43,    44,
      45,    46,    47,    48
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char yystos[] =
{
       0,    50,     0,     1,     5,    14,    15,    30,    51,    57,
      59,    62,    67,     1,    67,    67,    67,    12,    35,    39,
      58,    63,    64,     8,     9,    18,    19,    20,    21,    22,
      23,    24,    25,    26,    27,    65,    66,    36,    31,    37,
      35,    35,    42,    42,    12,    40,    52,    60,    61,    67,
      61,    67,    67,    66,    12,     1,    38,    53,    54,    55,
      66,    36,    41,    12,    39,    36,    43,    43,    39,    66,
       1,    67,    12,    60,    66,    31,    40,    74,    75,    40,
      34,    34,    56,    66,    40,    12,    13,    72,    35,    74,
      12,    66,    15,     3,    10,    11,    31,    32,    33,    67,
      68,    69,    70,    73,    76,    78,    80,    61,    13,    66,
      35,    77,    39,    42,    43,    44,    45,    46,    47,    48,
      36,    14,    69,    76,    35,    69,    43,    48,    69,    48,
      69,    69,    69,    69,    69,    48,    69,    74,    36,    48,
      69,    71,    40,    69,    69,    69,    69,    16,    36,    41,
      74,    69,     4,    79,    74,    13,     3
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrlab1


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { 								\
      yyerror ("syntax error: cannot back up");\
      YYERROR;							\
    }								\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

/* YYLLOC_DEFAULT -- Compute the default location (before the actions
   are run).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)         \
  Current.first_line   = Rhs[1].first_line;      \
  Current.first_column = Rhs[1].first_column;    \
  Current.last_line    = Rhs[N].last_line;       \
  Current.last_column  = Rhs[N].last_column;
#endif

/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (YYLEX_PARAM)
#else
# define YYLEX yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (0)

# define YYDSYMPRINT(Args)			\
do {						\
  if (yydebug)					\
    yysymprint Args;				\
} while (0)

# define YYDSYMPRINTF(Title, Token, Value, Location)		\
do {								\
  if (yydebug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      yysymprint (stderr, 					\
                  Token, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (cinluded).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_stack_print (short *bottom, short *top)
#else
static void
yy_stack_print (bottom, top)
    short *bottom;
    short *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_reduce_print (int yyrule)
#else
static void
yy_reduce_print (yyrule)
    int yyrule;
#endif
{
  int yyi;
  unsigned int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
             yyrule - 1, yylno);
  /* Print the symbols being reduced, and their result.  */
  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YYDSYMPRINT(Args)
# define YYDSYMPRINTF(Title, Token, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#if YYMAXDEPTH == 0
# undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
yystrlen (const char *yystr)
#   else
yystrlen (yystr)
     const char *yystr;
#   endif
{
  register const char *yys = yystr;

  while (*yys++ != '\0')
    continue;

  return yys - yystr - 1;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
yystpcpy (char *yydest, const char *yysrc)
#   else
yystpcpy (yydest, yysrc)
     char *yydest;
     const char *yysrc;
#   endif
{
  register char *yyd = yydest;
  register const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
#else
static void
yysymprint (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  if (yytype < YYNTOKENS)
    {
      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
# ifdef YYPRINT
      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
    }
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  switch (yytype)
    {
      default:
        break;
    }
  YYFPRINTF (yyoutput, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yydestruct (int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yytype, yyvaluep)
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  switch (yytype)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM);
# else
int yyparse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */



/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;



/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM)
# else
int yyparse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  
  register int yystate;
  register int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short	yyssa[YYINITDEPTH];
  short *yyss = yyssa;
  register short *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  register YYSTYPE *yyvsp;



#define YYPOPSTACK   (yyvsp--, yyssp--)

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	short *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow ("parser stack overflow",
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyoverflowlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	short *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyoverflowlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */
  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  yystate = yyn;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 4:
#line 71 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_decl_add (yyvsp[0].expr); }
    break;

  case 5:
#line 72 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_decl_add (yyvsp[0].expr); }
    break;

  case 6:
#line 73 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_decl_add (yyvsp[0].expr); }
    break;

  case 7:
#line 74 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_basic_error ("Expecting a declaration"); }
    break;

  case 9:
#line 83 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_class_add (yyvsp[0].expr); }
    break;

  case 10:
#line 86 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 11:
#line 87 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 12:
#line 88 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_basic_error ("Expecting a class field (property or method"); }
    break;

  case 13:
#line 93 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("prop", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 14:
#line 94 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_basic_error ("Expecting an identifier\n"); }
    break;

  case 15:
#line 99 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_method_create (yyvsp[-1].expr, yyvsp[0].expr);  }
    break;

  case 16:
#line 102 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_method_finish (yyvsp[0].expr); }
    break;

  case 17:
#line 107 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_class_create (yyvsp[0].expr, NULL); }
    break;

  case 18:
#line 109 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_class_finish (); }
    break;

  case 19:
#line 111 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_basic_error ("Missing an identifier"); }
    break;

  case 20:
#line 116 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("global", yyvsp[0].expr, yyvsp[-2].expr); }
    break;

  case 21:
#line 118 "parser/basiclike/langbasic_yacc.y"
    {
      yyvsp[-6].expr->type->array_type = XL_TYPE_ARRAY_TYPE_DYNAMIC;
      yyvsp[-6].expr->type->array_size = 0;
      yyval.expr = xl_lang_efnct_create2 ("global", yyvsp[-2].expr, yyvsp[-6].expr);
    }
    break;

  case 22:
#line 124 "parser/basiclike/langbasic_yacc.y"
    {
      yyvsp[0].expr->type->array_type = XL_TYPE_ARRAY_TYPE_FIXED;
      yyvsp[0].expr->type->array_size = yyvsp[-3].val_int;
      yyval.expr = xl_lang_efnct_create2 ("global", yyvsp[0].expr, yyvsp[-5].expr);
    }
    break;

  case 23:
#line 154 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_fnct_add_param (yyvsp[0].expr, yyvsp[-2].expr); }
    break;

  case 24:
#line 156 "parser/basiclike/langbasic_yacc.y"
    {
      yyvsp[0].expr->type->array_type = XL_TYPE_ARRAY_TYPE_DYNAMIC;
      yyvsp[0].expr->type->array_size = 0;
      xl_lang_fnct_add_param (yyvsp[0].expr, yyvsp[-4].expr);
    }
    break;

  case 25:
#line 162 "parser/basiclike/langbasic_yacc.y"
    {
      yyvsp[0].expr->type->array_type = XL_TYPE_ARRAY_TYPE_FIXED;
      yyvsp[0].expr->type->array_size = yyvsp[-3].val_int;
      xl_lang_fnct_add_param (yyvsp[0].expr, yyvsp[-5].expr);
    }
    break;

  case 29:
#line 177 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_fnct_create (NULL, yyvsp[0].expr);  }
    break;

  case 30:
#line 182 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_fnct_set_type (yyvsp[-3].expr);
    yyval.expr = xl_lang_fnct_finish (yyvsp[-2].expr); 
  }
    break;

  case 31:
#line 187 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_fnct_create (xl_lang_type_create (XL_TYPE_TYPE_VOID, XL_TYPE_ARRAY_TYPE_NONE, 0, NULL), yyvsp[0].expr);  }
    break;

  case 32:
#line 191 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_fnct_finish (yyvsp[-2].expr); }
    break;

  case 33:
#line 199 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_VOID;    }
    break;

  case 34:
#line 200 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_CHAR;    }
    break;

  case 35:
#line 201 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_UCHAR;   }
    break;

  case 36:
#line 202 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_SHORT;   }
    break;

  case 37:
#line 203 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_USHORT;  }
    break;

  case 38:
#line 204 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_INT;     }
    break;

  case 39:
#line 205 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_UINT;    }
    break;

  case 40:
#line 206 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_STRING;  }
    break;

  case 41:
#line 207 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_FLOAT;   }
    break;

  case 42:
#line 208 "parser/basiclike/langbasic_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_DOUBLE;  }
    break;

  case 43:
#line 212 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_type_create (yyvsp[0].xtype, XL_TYPE_ARRAY_TYPE_NONE, 0, NULL); }
    break;

  case 44:
#line 213 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_expr_new (); }
    break;

  case 45:
#line 214 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_expr_new (); }
    break;

  case 46:
#line 219 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr =  xl_expr_new_identifier (yyvsp[0].identifier); }
    break;

  case 47:
#line 223 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_data_string_create (yyvsp[0].val_string);   }
    break;

  case 48:
#line 224 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_data_integer_create (yyvsp[0].val_int);  }
    break;

  case 49:
#line 225 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_data_float_create (yyvsp[0].val_float);    }
    break;

  case 50:
#line 226 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_data_bool_create (TRUE);   }
    break;

  case 51:
#line 227 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_data_bool_create (FALSE);  }
    break;

  case 52:
#line 235 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 53:
#line 236 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 54:
#line 237 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 55:
#line 238 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 56:
#line 239 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("+", yyvsp[-2].expr, yyvsp[0].expr); }
    break;

  case 57:
#line 240 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("*", yyvsp[-2].expr, yyvsp[0].expr); }
    break;

  case 58:
#line 241 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("-", yyvsp[-2].expr, yyvsp[0].expr); }
    break;

  case 59:
#line 242 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("/", yyvsp[-2].expr, yyvsp[0].expr); }
    break;

  case 60:
#line 243 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("<=", yyvsp[-3].expr, yyvsp[0].expr); }
    break;

  case 61:
#line 244 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 (">=", yyvsp[-3].expr, yyvsp[0].expr); }
    break;

  case 62:
#line 245 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("<", yyvsp[-2].expr, yyvsp[0].expr); }
    break;

  case 63:
#line 246 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 (">", yyvsp[-2].expr, yyvsp[0].expr); }
    break;

  case 64:
#line 247 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("==", yyvsp[-3].expr, yyvsp[0].expr); }
    break;

  case 65:
#line 248 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("<>", yyvsp[-3].expr, yyvsp[0].expr); }
    break;

  case 66:
#line 252 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("[]", yyvsp[-3].expr, yyvsp[-1].expr); }
    break;

  case 68:
#line 257 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_call_add (yyvsp[0].expr); }
    break;

  case 69:
#line 258 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_call_add (yyvsp[0].expr); }
    break;

  case 72:
#line 273 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_block_add (yyvsp[0].expr); }
    break;

  case 73:
#line 274 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_block_add (yyvsp[0].expr); }
    break;

  case 74:
#line 275 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_block_add (yyvsp[0].expr); }
    break;

  case 75:
#line 283 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_block_begin (); }
    break;

  case 76:
#line 285 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_block_end (); }
    break;

  case 77:
#line 295 "parser/basiclike/langbasic_yacc.y"
    { xl_lang_call_begin (x_string_get_str (yyvsp[0].expr->identifier)); }
    break;

  case 78:
#line 297 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_call_end (); }
    break;

  case 79:
#line 301 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("=", yyvsp[-2].expr, yyvsp[0].expr); }
    break;

  case 80:
#line 334 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = NULL; }
    break;

  case 81:
#line 335 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 82:
#line 344 "parser/basiclike/langbasic_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("if", yyvsp[-6].expr, yyvsp[-3].expr); }
    break;


    }

/* Line 999 of yacc.c.  */
#line 1590 "langbasic_yacc.c"

  yyvsp -= yylen;
  yyssp -= yylen;


  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (YYPACT_NINF < yyn && yyn < YYLAST)
	{
	  YYSIZE_T yysize = 0;
	  int yytype = YYTRANSLATE (yychar);
	  const char* yyprefix;
	  char *yymsg;
	  int yyx;

	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  int yyxbegin = yyn < 0 ? -yyn : 0;

	  /* Stay within bounds of both yycheck and yytname.  */
	  int yychecklim = YYLAST - yyn;
	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
	  int yycount = 0;

	  yyprefix = ", expecting ";
	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	      {
		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
		yycount += 1;
		if (yycount == 5)
		  {
		    yysize = 0;
		    break;
		  }
	      }
	  yysize += (sizeof ("syntax error, unexpected ")
		     + yystrlen (yytname[yytype]));
	  yymsg = (char *) YYSTACK_ALLOC (yysize);
	  if (yymsg != 0)
	    {
	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
	      yyp = yystpcpy (yyp, yytname[yytype]);

	      if (yycount < 5)
		{
		  yyprefix = ", expecting ";
		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
		      {
			yyp = yystpcpy (yyp, yyprefix);
			yyp = yystpcpy (yyp, yytname[yyx]);
			yyprefix = " or ";
		      }
		}
	      yyerror (yymsg);
	      YYSTACK_FREE (yymsg);
	    }
	  else
	    yyerror ("syntax error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror ("syntax error");
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      /* Return failure if at end of input.  */
      if (yychar == YYEOF)
        {
	  /* Pop the error token.  */
          YYPOPSTACK;
	  /* Pop the rest of the stack.  */
	  while (yyss < yyssp)
	    {
	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
	      yydestruct (yystos[*yyssp], yyvsp);
	      YYPOPSTACK;
	    }
	  YYABORT;
        }

      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
      yydestruct (yytoken, &yylval);
      yychar = YYEMPTY;

    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*----------------------------------------------------.
| yyerrlab1 -- error raised explicitly by an action.  |
`----------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
      yydestruct (yystos[yystate], yyvsp);
      yyvsp--;
      yystate = *--yyssp;

      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  YYDPRINTF ((stderr, "Shifting error token, "));

  *++yyvsp = yylval;


  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*----------------------------------------------.
| yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
yyoverflowlab:
  yyerror ("parser stack overflow");
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  return yyresult;
}


#line 347 "parser/basiclike/langbasic_yacc.y"



